@@ -4,24 +4,18 @@ Run an optimization calculation on a molecule using Rowan.
 See documentation at: https://docs.rowansci.com/science/quantum-chemistry/geometry-optimization
 """
 
-import json
-
 from stjames import Molecule
 
 import rowan
 
 # rowan.api_key = ""
 
-# Run calculation remotely
-result = rowan.compute(
-    Molecule.from_smiles("O"),
-    workflow_type="basic_calculation",
-    name="Water Optimization",
-    settings={
-        "method": "GFN2-xTB",
-        "tasks": ["optimize"],
-    },
+result = rowan.submit_basic_calculation_workflow(
+    initial_molecule=Molecule.from_smiles("O"),
+    method="GFN2-xTB",
+    tasks=["optimize"],
     engine="xtb",
+    name="Water Optimization",
 )
 
-print(json.dumps(result, indent=4))
+print(result)
